# frozen_string_literal: true

#
# Cookbook:: docker-ce-cookbook
# Recipe:: default
#
# Copyright: 2019, Pharmony SA, All Rights Reserved.
#

# `node_distribution` in the recipe body (See recipe bottom)
Chef::Recipe.send(:include, DockerCeCookbook::Helper)
# `build_docker_version` in `package`
Chef::Resource::AptPackage.send(:include, DockerCeCookbook::Helper)
# `node_distribution` in `apt_repository`
Chef::Resource::AptRepository.send(:include, DockerCeCookbook::Helper)

#
# Clean up
#
package %w[
  docker
  docker-engine
  docker.io
  containerd
  runc
] do
  action :remove
end

#
# Dependencies
#
package %w[
  apt-transport-https
  ca-certificates
  curl
  gnupg2
  software-properties-common
] do
  action :install
end

#
# Docker APT repo
#
apt_repository 'docker' do
  uri           'https://download.docker.com/linux/debian'
  arch          'amd64'
  components    ['stable']
  distribution  node_distribution
  key           'https://download.docker.com/linux/debian/gpg'
  action        :add
end

#
# Docker Installation
#
case node['platform']
when 'debian'
  case node_distribution
  when 'jessie'
    package 'docker-ce' do
      version(lazy { build_docker_version })
      action :install
    end
  when 'stretch'
    package 'docker-ce' do
      version(lazy { build_docker_version })
      action :install
    end

    # docker-ce-cli needed only after version 18.09
    if node[:docker_ce][:version] == 'latest' ||
       node[:docker_ce][:version].to_f >= 18.09
      package 'docker-ce-cli' do
        version(lazy { build_docker_version })
        action :install
      end
    end

    package 'containerd.io' do
      action :install
    end
  end
end
